"""Resources names. File automatically generated by PyGuiSignal. Modifications may be overwritten."""
from mhelper import ResourceIcon
add = ResourceIcon( ":/bio42/add.svg" )
annotation = ResourceIcon( ":/bio42/annotation.svg" )
browse = ResourceIcon( ":/bio42/browse.svg" )
browser = ResourceIcon( ":/bio42/browser.svg" )
csv = ResourceIcon( ":/bio42/csv.svg" )
database = ResourceIcon( ":/bio42/database.svg" )
delete = ResourceIcon( ":/bio42/delete.svg" )
disconnect = ResourceIcon( ":/bio42/disconnect.svg" )
endpoint = ResourceIcon( ":/bio42/endpoint.svg" )
file = ResourceIcon( ":/bio42/file.svg" )
go = ResourceIcon( ":/bio42/go.svg" )
go_to_top = ResourceIcon( ":/bio42/go_to_top.svg" )
help = ResourceIcon( ":/bio42/help.svg" )
information = ResourceIcon( ":/bio42/information.svg" )
network = ResourceIcon( ":/bio42/network.svg" )
next = ResourceIcon( ":/bio42/next.svg" )
optimise = ResourceIcon( ":/bio42/optimise.svg" )
package = ResourceIcon( ":/bio42/package.svg" )
parcel = ResourceIcon( ":/bio42/parcel.svg" )
pickle = ResourceIcon( ":/bio42/pickle.svg" )
refresh = ResourceIcon( ":/bio42/refresh.svg" )
run_query = ResourceIcon( ":/bio42/run_query.svg" )
save = ResourceIcon( ":/bio42/save.svg" )
script = ResourceIcon( ":/bio42/script.svg" )
select_database = ResourceIcon( ":/bio42/select_database.svg" )
send = ResourceIcon( ":/bio42/send.svg" )
sequence = ResourceIcon( ":/bio42/sequence.svg" )
settings = ResourceIcon( ":/bio42/settings.svg" )
similarity = ResourceIcon( ":/bio42/similarity.svg" )
start = ResourceIcon( ":/bio42/start.svg" )
stop = ResourceIcon( ":/bio42/stop.svg" )
taxonomy = ResourceIcon( ":/bio42/taxonomy.svg" )
type_edge = ResourceIcon( ":/bio42/type_edge.svg" )
type_endpoint = ResourceIcon( ":/bio42/type_endpoint.svg" )
type_graph = ResourceIcon( ":/bio42/type_graph.svg" )
type_node = ResourceIcon( ":/bio42/type_node.svg" )
verify = ResourceIcon( ":/bio42/verify.svg" )
view_browser = ResourceIcon( ":/bio42/view_browser.svg" )
view_list = ResourceIcon( ":/bio42/view_list.svg" )
webpage = ResourceIcon( ":/bio42/webpage.svg" )
whiteboard = ResourceIcon( ":/bio42/whiteboard.png" )
wizard = ResourceIcon( ":/bio42/wizard.svg" )