"""
Subpackage containing the commands associated with downloading information.
"""

from .accessions import download_accessions, download_annotations
from .taxonomy import download_taxonomy
from .ontology import download_ontology