# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/martinrusilowicz/work/apps/bio42/bio42_gui/forms/designer/frm_database_designer.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def __init__(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(790, 695)
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMinimumSize(QtCore.QSize(0, 32))
        self.groupBox.setStyleSheet("")
        self.groupBox.setTitle("")
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_3.setSpacing(8)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.verticalLayout_3.addWidget(self.label_5)
        self.TXT_SERVER = QtWidgets.QLineEdit(self.groupBox)
        self.TXT_SERVER.setReadOnly(True)
        self.TXT_SERVER.setObjectName("TXT_SERVER")
        self.verticalLayout_3.addWidget(self.TXT_SERVER)
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_3.addWidget(self.label_2)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.LBL_STATUS_COLOUR = QtWidgets.QLabel(self.groupBox)
        self.LBL_STATUS_COLOUR.setMinimumSize(QtCore.QSize(10, 0))
        self.LBL_STATUS_COLOUR.setMaximumSize(QtCore.QSize(10, 16777215))
        self.LBL_STATUS_COLOUR.setText("")
        self.LBL_STATUS_COLOUR.setObjectName("LBL_STATUS_COLOUR")
        self.horizontalLayout_2.addWidget(self.LBL_STATUS_COLOUR)
        self.TXT_STATUS = QtWidgets.QLineEdit(self.groupBox)
        self.TXT_STATUS.setReadOnly(True)
        self.TXT_STATUS.setObjectName("TXT_STATUS")
        self.horizontalLayout_2.addWidget(self.TXT_STATUS)
        self.verticalLayout_3.addLayout(self.horizontalLayout_2)
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.verticalLayout_3.addWidget(self.label_4)
        self.TXT_DATABASE = QtWidgets.QLineEdit(self.groupBox)
        self.TXT_DATABASE.setReadOnly(True)
        self.TXT_DATABASE.setObjectName("TXT_DATABASE")
        self.verticalLayout_3.addWidget(self.TXT_DATABASE)
        self.verticalLayout.addWidget(self.groupBox)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        self.groupBox_2 = QtWidgets.QGroupBox(Dialog)
        self.groupBox_2.setTitle("")
        self.groupBox_2.setObjectName("groupBox_2")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setSpacing(12)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.BTN_ENDPOINT = QtWidgets.QCommandLinkButton(self.groupBox_2)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/bio42/database.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_ENDPOINT.setIcon(icon)
        self.BTN_ENDPOINT.setObjectName("BTN_ENDPOINT")
        self.verticalLayout_4.addWidget(self.BTN_ENDPOINT)
        self.GRP_ENDPOINT = QtWidgets.QGroupBox(self.groupBox_2)
        self.GRP_ENDPOINT.setTitle("")
        self.GRP_ENDPOINT.setObjectName("GRP_ENDPOINT")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.GRP_ENDPOINT)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.CMB_ENDPOINT = QtWidgets.QComboBox(self.GRP_ENDPOINT)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.CMB_ENDPOINT.sizePolicy().hasHeightForWidth())
        self.CMB_ENDPOINT.setSizePolicy(sizePolicy)
        self.CMB_ENDPOINT.setObjectName("CMB_ENDPOINT")
        self.horizontalLayout.addWidget(self.CMB_ENDPOINT)
        self.BTN_UPDATE_ENDPOINT = QtWidgets.QPushButton(self.GRP_ENDPOINT)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/bio42/refresh.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_UPDATE_ENDPOINT.setIcon(icon1)
        self.BTN_UPDATE_ENDPOINT.setIconSize(QtCore.QSize(16, 16))
        self.BTN_UPDATE_ENDPOINT.setObjectName("BTN_UPDATE_ENDPOINT")
        self.horizontalLayout.addWidget(self.BTN_UPDATE_ENDPOINT)
        self.verticalLayout_4.addWidget(self.GRP_ENDPOINT)
        self.BTN_START = QtWidgets.QCommandLinkButton(self.groupBox_2)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/bio42/start.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_START.setIcon(icon2)
        self.BTN_START.setObjectName("BTN_START")
        self.verticalLayout_4.addWidget(self.BTN_START)
        self.BTN_STOP = QtWidgets.QCommandLinkButton(self.groupBox_2)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/bio42/stop.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_STOP.setIcon(icon3)
        self.BTN_STOP.setObjectName("BTN_STOP")
        self.verticalLayout_4.addWidget(self.BTN_STOP)
        self.BTN_REFRESH = QtWidgets.QCommandLinkButton(self.groupBox_2)
        self.BTN_REFRESH.setIcon(icon1)
        self.BTN_REFRESH.setObjectName("BTN_REFRESH")
        self.verticalLayout_4.addWidget(self.BTN_REFRESH)
        self.BTN_DATABASE = QtWidgets.QCommandLinkButton(self.groupBox_2)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/bio42/select_database.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_DATABASE.setIcon(icon4)
        self.BTN_DATABASE.setObjectName("BTN_DATABASE")
        self.verticalLayout_4.addWidget(self.BTN_DATABASE)
        self.GRP_DATABASE = QtWidgets.QGroupBox(self.groupBox_2)
        self.GRP_DATABASE.setTitle("")
        self.GRP_DATABASE.setObjectName("GRP_DATABASE")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.GRP_DATABASE)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.CMB_DATABASE = QtWidgets.QComboBox(self.GRP_DATABASE)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.CMB_DATABASE.sizePolicy().hasHeightForWidth())
        self.CMB_DATABASE.setSizePolicy(sizePolicy)
        self.CMB_DATABASE.setObjectName("CMB_DATABASE")
        self.horizontalLayout_4.addWidget(self.CMB_DATABASE)
        self.BTN_NEWDB = QtWidgets.QPushButton(self.GRP_DATABASE)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/bio42/add.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_NEWDB.setIcon(icon5)
        self.BTN_NEWDB.setIconSize(QtCore.QSize(16, 16))
        self.BTN_NEWDB.setObjectName("BTN_NEWDB")
        self.horizontalLayout_4.addWidget(self.BTN_NEWDB)
        self.BTN_APPLYDB = QtWidgets.QPushButton(self.GRP_DATABASE)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/bio42/save.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_APPLYDB.setIcon(icon6)
        self.BTN_APPLYDB.setIconSize(QtCore.QSize(16, 16))
        self.BTN_APPLYDB.setObjectName("BTN_APPLYDB")
        self.horizontalLayout_4.addWidget(self.BTN_APPLYDB)
        self.verticalLayout_4.addWidget(self.GRP_DATABASE)
        self.BTN_OPEN_BROWSER = QtWidgets.QCommandLinkButton(self.groupBox_2)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/bio42/browser.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_OPEN_BROWSER.setIcon(icon7)
        self.BTN_OPEN_BROWSER.setObjectName("BTN_OPEN_BROWSER")
        self.verticalLayout_4.addWidget(self.BTN_OPEN_BROWSER)
        self.BTN_SHOW_CONFIG = QtWidgets.QCommandLinkButton(self.groupBox_2)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/bio42/settings.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_SHOW_CONFIG.setIcon(icon8)
        self.BTN_SHOW_CONFIG.setObjectName("BTN_SHOW_CONFIG")
        self.verticalLayout_4.addWidget(self.BTN_SHOW_CONFIG)
        self.verticalLayout.addWidget(self.groupBox_2)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.label_5.setText(_translate("Dialog", "Server"))
        self.label_2.setText(_translate("Dialog", "Status"))
        self.label_4.setText(_translate("Dialog", "Database"))
        self.BTN_ENDPOINT.setText(_translate("Dialog", "Select server"))
        self.BTN_ENDPOINT.setDescription(_translate("Dialog", "Select the Neo4j server you\'d like to control."))
        self.CMB_ENDPOINT.setToolTip(_translate("Dialog", "Endpoint to view or modify"))
        self.BTN_UPDATE_ENDPOINT.setToolTip(_translate("Dialog", "Change database - you can only do this whilst the server is stopped."))
        self.BTN_UPDATE_ENDPOINT.setText(_translate("Dialog", "Update"))
        self.BTN_START.setToolTip(_translate("Dialog", "Start server"))
        self.BTN_START.setText(_translate("Dialog", "Start"))
        self.BTN_START.setDescription(_translate("Dialog", "Start the Neo4j server."))
        self.BTN_STOP.setToolTip(_translate("Dialog", "Stop server"))
        self.BTN_STOP.setText(_translate("Dialog", "Stop"))
        self.BTN_STOP.setDescription(_translate("Dialog", "Stop the Neo4j server."))
        self.BTN_REFRESH.setText(_translate("Dialog", "Refresh information"))
        self.BTN_REFRESH.setDescription(_translate("Dialog", "Update the information shown on this display"))
        self.BTN_DATABASE.setText(_translate("Dialog", "Change database"))
        self.BTN_DATABASE.setDescription(_translate("Dialog", "Select a new database. Your server must be stopped first."))
        self.CMB_DATABASE.setToolTip(_translate("Dialog", "Change database - you can only do this whilst the server is stopped."))
        self.BTN_NEWDB.setToolTip(_translate("Dialog", "Change database - you can only do this whilst the server is stopped."))
        self.BTN_NEWDB.setText(_translate("Dialog", "New"))
        self.BTN_APPLYDB.setToolTip(_translate("Dialog", "Change database - you can only do this whilst the server is stopped."))
        self.BTN_APPLYDB.setText(_translate("Dialog", "Apply"))
        self.BTN_OPEN_BROWSER.setText(_translate("Dialog", "Open in browser"))
        self.BTN_OPEN_BROWSER.setDescription(_translate("Dialog", "Open the Neo4j browser for the selected database."))
        self.BTN_SHOW_CONFIG.setText(_translate("Dialog", "Select configuration file in Explorer"))
        self.BTN_SHOW_CONFIG.setDescription(_translate("Dialog", "Shows the Neo4j configuration file in your system explorer."))


