# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/martinrusilowicz/work/apps/bio42/bio42_gui/forms/designer/frm_b42main_designer.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1521, 1246)
        MainWindow.setStyleSheet("")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.PAGER_MAIN = QtWidgets.QTabWidget(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.PAGER_MAIN.sizePolicy().hasHeightForWidth())
        self.PAGER_MAIN.setSizePolicy(sizePolicy)
        self.PAGER_MAIN.setDocumentMode(True)
        self.PAGER_MAIN.setObjectName("PAGER_MAIN")
        self.PAG_INTRO = QtWidgets.QWidget()
        self.PAG_INTRO.setObjectName("PAG_INTRO")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.PAG_INTRO)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.LBL_INTRO = QtWidgets.QLabel(self.PAG_INTRO)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.LBL_INTRO.sizePolicy().hasHeightForWidth())
        self.LBL_INTRO.setSizePolicy(sizePolicy)
        self.LBL_INTRO.setStyleSheet("background: white;")
        self.LBL_INTRO.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.LBL_INTRO.setWordWrap(True)
        self.LBL_INTRO.setObjectName("LBL_INTRO")
        self.gridLayout_2.addWidget(self.LBL_INTRO, 0, 0, 1, 1)
        self.PAGER_MAIN.addTab(self.PAG_INTRO, "")
        self.PAG_ENDPOINTS = QtWidgets.QWidget()
        self.PAG_ENDPOINTS.setObjectName("PAG_ENDPOINTS")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.PAG_ENDPOINTS)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.frame = QtWidgets.QFrame(self.PAG_ENDPOINTS)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setProperty("style", "contents")
        self.frame.setObjectName("frame")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.frame)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.frame)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_2.addWidget(self.label_2)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.BTN_WIZARD = QtWidgets.QToolButton(self.frame)
        self.BTN_WIZARD.setMinimumSize(QtCore.QSize(96, 96))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/bio42/wizard.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_WIZARD.setIcon(icon)
        self.BTN_WIZARD.setIconSize(QtCore.QSize(64, 64))
        self.BTN_WIZARD.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_WIZARD.setProperty("style", "item")
        self.BTN_WIZARD.setObjectName("BTN_WIZARD")
        self.horizontalLayout_5.addWidget(self.BTN_WIZARD)
        self.BTN_ENDPOINT_DATABASE = QtWidgets.QToolButton(self.frame)
        self.BTN_ENDPOINT_DATABASE.setMinimumSize(QtCore.QSize(96, 96))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/bio42/database.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_ENDPOINT_DATABASE.setIcon(icon1)
        self.BTN_ENDPOINT_DATABASE.setIconSize(QtCore.QSize(64, 64))
        self.BTN_ENDPOINT_DATABASE.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_ENDPOINT_DATABASE.setProperty("style", "item")
        self.BTN_ENDPOINT_DATABASE.setObjectName("BTN_ENDPOINT_DATABASE")
        self.horizontalLayout_5.addWidget(self.BTN_ENDPOINT_DATABASE)
        self.BTN_ENDPOINT_PACKAGE = QtWidgets.QToolButton(self.frame)
        self.BTN_ENDPOINT_PACKAGE.setMinimumSize(QtCore.QSize(96, 96))
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/bio42/parcel.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_ENDPOINT_PACKAGE.setIcon(icon2)
        self.BTN_ENDPOINT_PACKAGE.setIconSize(QtCore.QSize(64, 64))
        self.BTN_ENDPOINT_PACKAGE.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_ENDPOINT_PACKAGE.setProperty("style", "item")
        self.BTN_ENDPOINT_PACKAGE.setObjectName("BTN_ENDPOINT_PACKAGE")
        self.horizontalLayout_5.addWidget(self.BTN_ENDPOINT_PACKAGE)
        self.BTN_ENDPOINT_MGRAPH = QtWidgets.QToolButton(self.frame)
        self.BTN_ENDPOINT_MGRAPH.setMinimumSize(QtCore.QSize(96, 96))
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/bio42/file.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_ENDPOINT_MGRAPH.setIcon(icon3)
        self.BTN_ENDPOINT_MGRAPH.setIconSize(QtCore.QSize(64, 64))
        self.BTN_ENDPOINT_MGRAPH.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_ENDPOINT_MGRAPH.setProperty("style", "item")
        self.BTN_ENDPOINT_MGRAPH.setObjectName("BTN_ENDPOINT_MGRAPH")
        self.horizontalLayout_5.addWidget(self.BTN_ENDPOINT_MGRAPH)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.label_4 = QtWidgets.QLabel(self.frame)
        self.label_4.setObjectName("label_4")
        self.verticalLayout_2.addWidget(self.label_4)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.BTN_ENDPOINT_TRANSFER = QtWidgets.QToolButton(self.frame)
        self.BTN_ENDPOINT_TRANSFER.setMinimumSize(QtCore.QSize(96, 96))
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/bio42/send.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_ENDPOINT_TRANSFER.setIcon(icon4)
        self.BTN_ENDPOINT_TRANSFER.setIconSize(QtCore.QSize(64, 64))
        self.BTN_ENDPOINT_TRANSFER.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_ENDPOINT_TRANSFER.setProperty("style", "item")
        self.BTN_ENDPOINT_TRANSFER.setObjectName("BTN_ENDPOINT_TRANSFER")
        self.horizontalLayout_7.addWidget(self.BTN_ENDPOINT_TRANSFER)
        self.BTN_ENDPOINT_DISCONNECT = QtWidgets.QToolButton(self.frame)
        self.BTN_ENDPOINT_DISCONNECT.setMinimumSize(QtCore.QSize(96, 96))
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/bio42/disconnect.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_ENDPOINT_DISCONNECT.setIcon(icon5)
        self.BTN_ENDPOINT_DISCONNECT.setIconSize(QtCore.QSize(64, 64))
        self.BTN_ENDPOINT_DISCONNECT.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_ENDPOINT_DISCONNECT.setProperty("style", "item")
        self.BTN_ENDPOINT_DISCONNECT.setObjectName("BTN_ENDPOINT_DISCONNECT")
        self.horizontalLayout_7.addWidget(self.BTN_ENDPOINT_DISCONNECT)
        self.BTN_DB_STATUS = QtWidgets.QToolButton(self.frame)
        self.BTN_DB_STATUS.setMinimumSize(QtCore.QSize(96, 96))
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/bio42/select_database.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_DB_STATUS.setIcon(icon6)
        self.BTN_DB_STATUS.setIconSize(QtCore.QSize(64, 64))
        self.BTN_DB_STATUS.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_DB_STATUS.setProperty("style", "item")
        self.BTN_DB_STATUS.setObjectName("BTN_DB_STATUS")
        self.horizontalLayout_7.addWidget(self.BTN_DB_STATUS)
        self.BTN_OPTIMISE = QtWidgets.QToolButton(self.frame)
        self.BTN_OPTIMISE.setMinimumSize(QtCore.QSize(96, 96))
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/bio42/optimise.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_OPTIMISE.setIcon(icon7)
        self.BTN_OPTIMISE.setIconSize(QtCore.QSize(64, 64))
        self.BTN_OPTIMISE.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_OPTIMISE.setProperty("style", "item")
        self.BTN_OPTIMISE.setObjectName("BTN_OPTIMISE")
        self.horizontalLayout_7.addWidget(self.BTN_OPTIMISE)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem1)
        self.verticalLayout_2.addLayout(self.horizontalLayout_7)
        self.gridLayout_3.addWidget(self.frame, 1, 0, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_3.addItem(spacerItem2, 2, 0, 1, 1)
        self.label_8 = QtWidgets.QLabel(self.PAG_ENDPOINTS)
        self.label_8.setObjectName("label_8")
        self.gridLayout_3.addWidget(self.label_8, 0, 0, 1, 1)
        self.PAGER_MAIN.addTab(self.PAG_ENDPOINTS, "")
        self.PAG_IMPORT = QtWidgets.QWidget()
        self.PAG_IMPORT.setObjectName("PAG_IMPORT")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.PAG_IMPORT)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.frame_2 = QtWidgets.QFrame(self.PAG_IMPORT)
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setProperty("style", "contents")
        self.frame_2.setObjectName("frame_2")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.frame_2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_5 = QtWidgets.QLabel(self.frame_2)
        self.label_5.setObjectName("label_5")
        self.verticalLayout.addWidget(self.label_5)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.BTN_IMPORT_SEQUENCES = QtWidgets.QToolButton(self.frame_2)
        self.BTN_IMPORT_SEQUENCES.setMinimumSize(QtCore.QSize(96, 96))
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/bio42/sequence.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_IMPORT_SEQUENCES.setIcon(icon8)
        self.BTN_IMPORT_SEQUENCES.setIconSize(QtCore.QSize(64, 64))
        self.BTN_IMPORT_SEQUENCES.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_IMPORT_SEQUENCES.setProperty("style", "item")
        self.BTN_IMPORT_SEQUENCES.setObjectName("BTN_IMPORT_SEQUENCES")
        self.horizontalLayout_3.addWidget(self.BTN_IMPORT_SEQUENCES)
        self.BTN_IMPORT_SIMILARITIES = QtWidgets.QToolButton(self.frame_2)
        self.BTN_IMPORT_SIMILARITIES.setMinimumSize(QtCore.QSize(96, 96))
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/bio42/similarity.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_IMPORT_SIMILARITIES.setIcon(icon9)
        self.BTN_IMPORT_SIMILARITIES.setIconSize(QtCore.QSize(64, 64))
        self.BTN_IMPORT_SIMILARITIES.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_IMPORT_SIMILARITIES.setProperty("style", "item")
        self.BTN_IMPORT_SIMILARITIES.setObjectName("BTN_IMPORT_SIMILARITIES")
        self.horizontalLayout_3.addWidget(self.BTN_IMPORT_SIMILARITIES)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem3)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.label_6 = QtWidgets.QLabel(self.frame_2)
        self.label_6.setObjectName("label_6")
        self.verticalLayout.addWidget(self.label_6)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.BTN_IMPORT_TAXONOMY = QtWidgets.QToolButton(self.frame_2)
        self.BTN_IMPORT_TAXONOMY.setMinimumSize(QtCore.QSize(96, 96))
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/bio42/taxonomy.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_IMPORT_TAXONOMY.setIcon(icon10)
        self.BTN_IMPORT_TAXONOMY.setIconSize(QtCore.QSize(64, 64))
        self.BTN_IMPORT_TAXONOMY.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_IMPORT_TAXONOMY.setProperty("style", "item")
        self.BTN_IMPORT_TAXONOMY.setObjectName("BTN_IMPORT_TAXONOMY")
        self.horizontalLayout_4.addWidget(self.BTN_IMPORT_TAXONOMY)
        self.BTN_IMPORT_ONTOLOGY = QtWidgets.QToolButton(self.frame_2)
        self.BTN_IMPORT_ONTOLOGY.setMinimumSize(QtCore.QSize(96, 96))
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/bio42/go.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_IMPORT_ONTOLOGY.setIcon(icon11)
        self.BTN_IMPORT_ONTOLOGY.setIconSize(QtCore.QSize(64, 64))
        self.BTN_IMPORT_ONTOLOGY.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_IMPORT_ONTOLOGY.setProperty("style", "item")
        self.BTN_IMPORT_ONTOLOGY.setObjectName("BTN_IMPORT_ONTOLOGY")
        self.horizontalLayout_4.addWidget(self.BTN_IMPORT_ONTOLOGY)
        self.BTN_IMPORT_ANNOTATIONS = QtWidgets.QToolButton(self.frame_2)
        self.BTN_IMPORT_ANNOTATIONS.setMinimumSize(QtCore.QSize(96, 96))
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/bio42/annotation.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_IMPORT_ANNOTATIONS.setIcon(icon12)
        self.BTN_IMPORT_ANNOTATIONS.setIconSize(QtCore.QSize(64, 64))
        self.BTN_IMPORT_ANNOTATIONS.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_IMPORT_ANNOTATIONS.setProperty("style", "item")
        self.BTN_IMPORT_ANNOTATIONS.setObjectName("BTN_IMPORT_ANNOTATIONS")
        self.horizontalLayout_4.addWidget(self.BTN_IMPORT_ANNOTATIONS)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem4)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.label_7 = QtWidgets.QLabel(self.frame_2)
        self.label_7.setObjectName("label_7")
        self.verticalLayout.addWidget(self.label_7)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.BTN_IMPORT_CSV = QtWidgets.QToolButton(self.frame_2)
        self.BTN_IMPORT_CSV.setMinimumSize(QtCore.QSize(96, 96))
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/bio42/csv.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_IMPORT_CSV.setIcon(icon13)
        self.BTN_IMPORT_CSV.setIconSize(QtCore.QSize(64, 64))
        self.BTN_IMPORT_CSV.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_IMPORT_CSV.setProperty("style", "item")
        self.BTN_IMPORT_CSV.setObjectName("BTN_IMPORT_CSV")
        self.horizontalLayout_8.addWidget(self.BTN_IMPORT_CSV)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem5)
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.gridLayout_4.addWidget(self.frame_2, 1, 0, 1, 1)
        spacerItem6 = QtWidgets.QSpacerItem(20, 619, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_4.addItem(spacerItem6, 2, 0, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.PAG_IMPORT)
        self.label_11.setObjectName("label_11")
        self.gridLayout_4.addWidget(self.label_11, 0, 0, 1, 1)
        self.PAGER_MAIN.addTab(self.PAG_IMPORT, "")
        self.PAG_QUERY = QtWidgets.QWidget()
        self.PAG_QUERY.setObjectName("PAG_QUERY")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.PAG_QUERY)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.label_12 = QtWidgets.QLabel(self.PAG_QUERY)
        self.label_12.setObjectName("label_12")
        self.verticalLayout_8.addWidget(self.label_12)
        self.frame_3 = QtWidgets.QFrame(self.PAG_QUERY)
        self.frame_3.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_3.setProperty("style", "contents")
        self.frame_3.setObjectName("frame_3")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.frame_3)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label_9 = QtWidgets.QLabel(self.frame_3)
        self.label_9.setObjectName("label_9")
        self.verticalLayout_3.addWidget(self.label_9)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.BTN_QUERY_INBUILT = QtWidgets.QToolButton(self.frame_3)
        self.BTN_QUERY_INBUILT.setMinimumSize(QtCore.QSize(96, 96))
        self.BTN_QUERY_INBUILT.setMaximumSize(QtCore.QSize(96, 96))
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/bio42/script.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_QUERY_INBUILT.setIcon(icon14)
        self.BTN_QUERY_INBUILT.setIconSize(QtCore.QSize(64, 64))
        self.BTN_QUERY_INBUILT.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_QUERY_INBUILT.setProperty("style", "item")
        self.BTN_QUERY_INBUILT.setObjectName("BTN_QUERY_INBUILT")
        self.horizontalLayout.addWidget(self.BTN_QUERY_INBUILT)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem7)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.verticalLayout_8.addWidget(self.frame_3)
        self.frame_6 = QtWidgets.QFrame(self.PAG_QUERY)
        self.frame_6.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_6.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_6.setProperty("style", "contents")
        self.frame_6.setObjectName("frame_6")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.frame_6)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.label_16 = QtWidgets.QLabel(self.frame_6)
        self.label_16.setObjectName("label_16")
        self.verticalLayout_7.addWidget(self.label_16)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.BTN_EXPORT_GEXF = QtWidgets.QToolButton(self.frame_6)
        self.BTN_EXPORT_GEXF.setMinimumSize(QtCore.QSize(96, 96))
        self.BTN_EXPORT_GEXF.setMaximumSize(QtCore.QSize(96, 96))
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/bio42/network.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_EXPORT_GEXF.setIcon(icon15)
        self.BTN_EXPORT_GEXF.setIconSize(QtCore.QSize(64, 64))
        self.BTN_EXPORT_GEXF.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_EXPORT_GEXF.setProperty("style", "item")
        self.BTN_EXPORT_GEXF.setObjectName("BTN_EXPORT_GEXF")
        self.horizontalLayout_6.addWidget(self.BTN_EXPORT_GEXF)
        self.BTN_EXPORT_CSV = QtWidgets.QToolButton(self.frame_6)
        self.BTN_EXPORT_CSV.setMinimumSize(QtCore.QSize(96, 96))
        self.BTN_EXPORT_CSV.setMaximumSize(QtCore.QSize(96, 96))
        self.BTN_EXPORT_CSV.setIcon(icon13)
        self.BTN_EXPORT_CSV.setIconSize(QtCore.QSize(64, 64))
        self.BTN_EXPORT_CSV.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_EXPORT_CSV.setProperty("style", "item")
        self.BTN_EXPORT_CSV.setObjectName("BTN_EXPORT_CSV")
        self.horizontalLayout_6.addWidget(self.BTN_EXPORT_CSV)
        self.BTN_EXPORT_HTML = QtWidgets.QToolButton(self.frame_6)
        self.BTN_EXPORT_HTML.setMinimumSize(QtCore.QSize(96, 96))
        self.BTN_EXPORT_HTML.setMaximumSize(QtCore.QSize(96, 96))
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/bio42/webpage.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_EXPORT_HTML.setIcon(icon16)
        self.BTN_EXPORT_HTML.setIconSize(QtCore.QSize(64, 64))
        self.BTN_EXPORT_HTML.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_EXPORT_HTML.setProperty("style", "item")
        self.BTN_EXPORT_HTML.setObjectName("BTN_EXPORT_HTML")
        self.horizontalLayout_6.addWidget(self.BTN_EXPORT_HTML)
        self.BTN_QUERY_PICKLE = QtWidgets.QToolButton(self.frame_6)
        self.BTN_QUERY_PICKLE.setMinimumSize(QtCore.QSize(96, 96))
        self.BTN_QUERY_PICKLE.setMaximumSize(QtCore.QSize(96, 96))
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/bio42/pickle.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_QUERY_PICKLE.setIcon(icon17)
        self.BTN_QUERY_PICKLE.setIconSize(QtCore.QSize(64, 64))
        self.BTN_QUERY_PICKLE.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_QUERY_PICKLE.setProperty("style", "item")
        self.BTN_QUERY_PICKLE.setObjectName("BTN_QUERY_PICKLE")
        self.horizontalLayout_6.addWidget(self.BTN_QUERY_PICKLE)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem8)
        self.verticalLayout_7.addLayout(self.horizontalLayout_6)
        self.verticalLayout_8.addWidget(self.frame_6)
        spacerItem9 = QtWidgets.QSpacerItem(20, 619, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem9)
        self.PAGER_MAIN.addTab(self.PAG_QUERY, "")
        self.PAG_MISC = QtWidgets.QWidget()
        self.PAG_MISC.setObjectName("PAG_MISC")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.PAG_MISC)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.label_13 = QtWidgets.QLabel(self.PAG_MISC)
        self.label_13.setObjectName("label_13")
        self.gridLayout_6.addWidget(self.label_13, 0, 0, 1, 1)
        self.frame_4 = QtWidgets.QFrame(self.PAG_MISC)
        self.frame_4.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_4.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_4.setProperty("style", "contents")
        self.frame_4.setObjectName("frame_4")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.frame_4)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.label_14 = QtWidgets.QLabel(self.frame_4)
        self.label_14.setObjectName("label_14")
        self.verticalLayout_4.addWidget(self.label_14)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.BTN_HELP = QtWidgets.QToolButton(self.frame_4)
        self.BTN_HELP.setMinimumSize(QtCore.QSize(96, 96))
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/bio42/help.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_HELP.setIcon(icon18)
        self.BTN_HELP.setIconSize(QtCore.QSize(64, 64))
        self.BTN_HELP.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_HELP.setProperty("style", "item")
        self.BTN_HELP.setObjectName("BTN_HELP")
        self.horizontalLayout_9.addWidget(self.BTN_HELP)
        self.BTN_INTERMAKE = QtWidgets.QToolButton(self.frame_4)
        self.BTN_INTERMAKE.setMinimumSize(QtCore.QSize(96, 96))
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(":/intermake/intermake_logo.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_INTERMAKE.setIcon(icon19)
        self.BTN_INTERMAKE.setIconSize(QtCore.QSize(64, 64))
        self.BTN_INTERMAKE.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_INTERMAKE.setProperty("style", "item")
        self.BTN_INTERMAKE.setObjectName("BTN_INTERMAKE")
        self.horizontalLayout_9.addWidget(self.BTN_INTERMAKE)
        self.BTN_SETTINGS = QtWidgets.QToolButton(self.frame_4)
        self.BTN_SETTINGS.setMinimumSize(QtCore.QSize(96, 96))
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(":/bio42/settings.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_SETTINGS.setIcon(icon20)
        self.BTN_SETTINGS.setIconSize(QtCore.QSize(64, 64))
        self.BTN_SETTINGS.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
        self.BTN_SETTINGS.setProperty("style", "item")
        self.BTN_SETTINGS.setObjectName("BTN_SETTINGS")
        self.horizontalLayout_9.addWidget(self.BTN_SETTINGS)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem10)
        self.verticalLayout_4.addLayout(self.horizontalLayout_9)
        self.gridLayout_6.addWidget(self.frame_4, 1, 0, 1, 1)
        spacerItem11 = QtWidgets.QSpacerItem(20, 619, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_6.addItem(spacerItem11, 2, 0, 1, 1)
        self.PAGER_MAIN.addTab(self.PAG_MISC, "")
        self.gridLayout.addWidget(self.PAGER_MAIN, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1521, 22))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        self.PAGER_MAIN.setCurrentIndex(4)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.LBL_INTRO.setText(_translate("MainWindow", "<html><head/><body><p><span style=\" font-size:xx-large; font-weight:600;\">B42</span></p><p><span style=\" font-style:italic;\">Version 0.0.0.0</span></p><p><span style=\" font-size:x-large; font-weight:600;\">Meta-graph</span></p><p><img src=\":/bio42/whiteboard.png\"/><br/></p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:large;\">The </span><a href=\"action:getting started\"><span style=\" font-size:large; font-weight:600; text-decoration: underline; color:#0000ff;\">getting started</span></a><span style=\" font-size:large;\"> window can help you begin!</span></li></ul></body></html>"))
        self.PAGER_MAIN.setTabText(self.PAGER_MAIN.indexOf(self.PAG_INTRO), _translate("MainWindow", "Introduction"))
        self.label_2.setText(_translate("MainWindow", "Open"))
        self.label_2.setProperty("style", _translate("MainWindow", "heading"))
        self.BTN_WIZARD.setStatusTip(_translate("MainWindow", "Connect to a Neo4j database."))
        self.BTN_WIZARD.setText(_translate("MainWindow", "Wizard"))
        self.BTN_ENDPOINT_DATABASE.setStatusTip(_translate("MainWindow", "Connect to a Neo4j database."))
        self.BTN_ENDPOINT_DATABASE.setText(_translate("MainWindow", "Server"))
        self.BTN_ENDPOINT_PACKAGE.setStatusTip(_translate("MainWindow", "Open a folder on disk. You can use this to prepare bulk data transfers or if you can\'t currently connect toa  a Neo4j database."))
        self.BTN_ENDPOINT_PACKAGE.setText(_translate("MainWindow", "Parcel"))
        self.BTN_ENDPOINT_MGRAPH.setStatusTip(_translate("MainWindow", "An MGraph file can be exported to a variety of outputs."))
        self.BTN_ENDPOINT_MGRAPH.setText(_translate("MainWindow", "File"))
        self.label_4.setText(_translate("MainWindow", "Maintain"))
        self.label_4.setProperty("style", _translate("MainWindow", "heading"))
        self.BTN_ENDPOINT_TRANSFER.setStatusTip(_translate("MainWindow", "Transfer data from one endpoint to another."))
        self.BTN_ENDPOINT_TRANSFER.setText(_translate("MainWindow", "Transfer"))
        self.BTN_ENDPOINT_DISCONNECT.setStatusTip(_translate("MainWindow", "Disconnect an endpoint. This removed the endpoint from BIO42 but does not remove the data from disk - you can always reopen the endpoint later."))
        self.BTN_ENDPOINT_DISCONNECT.setText(_translate("MainWindow", "Disconnect"))
        self.BTN_DB_STATUS.setStatusTip(_translate("MainWindow", "Connect to a Neo4j database."))
        self.BTN_DB_STATUS.setText(_translate("MainWindow", "Database"))
        self.BTN_OPTIMISE.setStatusTip(_translate("MainWindow", "Connect to a Neo4j database."))
        self.BTN_OPTIMISE.setText(_translate("MainWindow", "Optimize"))
        self.label_8.setText(_translate("MainWindow", "Open an endpoint so you have somewhere to send your data."))
        self.label_8.setProperty("style", _translate("MainWindow", "helpbox"))
        self.PAGER_MAIN.setTabText(self.PAGER_MAIN.indexOf(self.PAG_ENDPOINTS), _translate("MainWindow", "Endpoints"))
        self.label_5.setText(_translate("MainWindow", "Genomics"))
        self.label_5.setProperty("style", _translate("MainWindow", "heading"))
        self.BTN_IMPORT_SEQUENCES.setText(_translate("MainWindow", "Sequences"))
        self.BTN_IMPORT_SIMILARITIES.setText(_translate("MainWindow", "Similarities"))
        self.label_6.setText(_translate("MainWindow", "Classification"))
        self.label_6.setProperty("style", _translate("MainWindow", "heading"))
        self.BTN_IMPORT_TAXONOMY.setText(_translate("MainWindow", "Taxonomy"))
        self.BTN_IMPORT_ONTOLOGY.setText(_translate("MainWindow", "Ontology"))
        self.BTN_IMPORT_ANNOTATIONS.setText(_translate("MainWindow", "Annotations"))
        self.label_7.setText(_translate("MainWindow", "Miscellaneous"))
        self.label_7.setProperty("style", _translate("MainWindow", "heading"))
        self.BTN_IMPORT_CSV.setText(_translate("MainWindow", "Custom"))
        self.label_11.setText(_translate("MainWindow", "You can import data to any endpoint that you have defined."))
        self.label_11.setProperty("style", _translate("MainWindow", "helpbox"))
        self.PAGER_MAIN.setTabText(self.PAGER_MAIN.indexOf(self.PAG_IMPORT), _translate("MainWindow", "Import"))
        self.label_12.setText(_translate("MainWindow", "Once you have data in your database you can run queries and export to a variety of formats."))
        self.label_12.setProperty("style", _translate("MainWindow", "helpbox"))
        self.label_9.setText(_translate("MainWindow", "Queries"))
        self.label_9.setProperty("style", _translate("MainWindow", "heading"))
        self.BTN_QUERY_INBUILT.setText(_translate("MainWindow", "Query"))
        self.label_16.setText(_translate("MainWindow", "Export"))
        self.label_16.setProperty("style", _translate("MainWindow", "heading"))
        self.BTN_EXPORT_GEXF.setToolTip(_translate("MainWindow", "Export to .GEXF"))
        self.BTN_EXPORT_GEXF.setText(_translate("MainWindow", "Gephi"))
        self.BTN_EXPORT_CSV.setToolTip(_translate("MainWindow", "Export to .CSV"))
        self.BTN_EXPORT_CSV.setText(_translate("MainWindow", "Excel"))
        self.BTN_EXPORT_HTML.setToolTip(_translate("MainWindow", "Export to .HTML"))
        self.BTN_EXPORT_HTML.setText(_translate("MainWindow", "Interative\n"
"web page"))
        self.BTN_QUERY_PICKLE.setToolTip(_translate("MainWindow", "Export to .PICKLE"))
        self.BTN_QUERY_PICKLE.setText(_translate("MainWindow", "Python"))
        self.PAGER_MAIN.setTabText(self.PAGER_MAIN.indexOf(self.PAG_QUERY), _translate("MainWindow", "Query"))
        self.label_13.setText(_translate("MainWindow", "Features that don\'t fall into any other category."))
        self.label_13.setProperty("style", _translate("MainWindow", "helpbox"))
        self.label_14.setText(_translate("MainWindow", "Miscellaneous"))
        self.label_14.setProperty("style", _translate("MainWindow", "heading"))
        self.BTN_HELP.setText(_translate("MainWindow", "Help"))
        self.BTN_INTERMAKE.setText(_translate("MainWindow", "Intermake"))
        self.BTN_SETTINGS.setText(_translate("MainWindow", "Settings"))
        self.PAGER_MAIN.setTabText(self.PAGER_MAIN.indexOf(self.PAG_MISC), _translate("MainWindow", "Miscellaneous"))


