"""
BIO42_GUI isn't a application, it's a library that just exports a
`GuiController`: `B42GuiController`.

This is used by BIO42 when the user runs the `GUI` command.
"""

from bio42_gui.controller.controller import B42GuiController
